@@ -25,21 +25,21 @@ def init(app):
 
 
 def register_graph(name):
-    with session_scope() as db_session:
-        return get_graph_id_from_name(db_session, name)
+    with session_scope() as session:
+        return get_graph_id_from_name(session, name)
 
 
 def add_background_job(func, graph_id, trigger, **schedule):
     def add_data():
-        with session_scope() as db_session:
-            add_value(db_session, graph_id, func())
+        with session_scope() as session:
+            add_value(session, graph_id, func())
 
     add_data()  # already call once, so it can be verified that the function works
     scheduler.add_job(func=add_data, trigger=trigger, **schedule)
 
 
 def get_custom_graphs():
-    with session_scope() as db_session:
-        result = get_graphs(db_session)
-        db_session.expunge_all()
+    with session_scope() as session:
+        result = get_graphs(session)
+        session.expunge_all()
         return result
