@@ -8,39 +8,28 @@ from sqlalchemy import and_, func
 from flask_monitoringdashboard.database import Request
 
 
-def get_latencies_in_timeframe(db_session, endpoint_id, start_date, end_date):
-    criterion = create_time_based_sample_criterion(start_date, end_date)
+def get_latencies_sample(session, endpoint_id, criterion, sample_size=500):
+    query = (
+        session.query(Request.duration).filter(Request.endpoint_id == endpoint_id,
+                                               *criterion)
+    )
+    # return random rows: See https://stackoverflow.com/a/60815
+    dialect = session.bind.dialect.name
 
-    items = db_session.query(Request.duration).filter(Request.endpoint_id == endpoint_id, *criterion).all()
+    if dialect == 'sqlite':
+        query = query.order_by(func.random())
+    elif dialect == 'mysql':
+        query = query.order_by(func.rand())
 
-    return [item.duration for item in items]
+    query = query.limit(sample_size)
+
+    return [item.duration for item in query.all()]
 
 
-def get_latencies_sample(db_session, endpoint_id, interval, sample_size=500):
-    criterion = create_time_based_sample_criterion(interval.start_date(), interval.end_date())
-
-    dialect = db_session.bind.dialect.name
-
-    if dialect in ['sqlite', 'mysql']:
-        order_by = func.random() if dialect == 'sqlite' else func.rand()
-
-        items = db_session.query(Request.duration) \
-            .filter(Request.endpoint_id == endpoint_id, *criterion) \
-            .order_by(order_by) \
-            .limit(sample_size) \
-            .all()
-
-        durations = [item.duration for item in items]
-
-        return durations
-    else:
-        return get_latencies_in_timeframe(db_session, endpoint_id, interval.start_date(), interval.end_date())
-
-
-def add_request(db_session, duration, endpoint_id, ip, group_by, status_code):
+def add_request(session, duration, endpoint_id, ip, group_by, status_code):
     """ Adds a request to the database. Returns the id.
     :param status_code:  status code of the request
-    :param db_session: session for the database
+    :param session: session for the database
     :param duration: duration of the request
     :param endpoint_id: id of the endpoint
     :param ip: IP address of the requester
@@ -54,17 +43,18 @@ def add_request(db_session, duration, endpoint_id, ip, group_by, status_code):
         group_by=group_by,
         status_code=status_code,
     )
-    db_session.add(request)
-    db_session.commit()
+    session.add(request)
+    session.commit()
     return request.id
 
 
-def get_date_of_first_request(db_session):
+def get_date_of_first_request(session):
     """ Returns the date (as unix timestamp) of the first request since FMD was deployed.
-    :param db_session: session for the database
+    :param session: session for the database
     :return time of the first request
     """
-    result = db_session.query(Request.time_requested).order_by(Request.time_requested).first()
+    result = session.query(Request.time_requested).order_by(
+        Request.time_requested).first()
     if result:
         return int(time.mktime(result[0].timetuple()))
     return -1
@@ -74,14 +64,14 @@ def create_time_based_sample_criterion(start_date, end_date):
     return and_(Request.time_requested > start_date, Request.time_requested <= end_date)
 
 
-def get_date_of_first_request_version(db_session, version):
+def get_date_of_first_request_version(session, version):
     """ Returns the date (as unix timestamp) of the first request in the current FMD version.
-    :param db_session: session for the database
+    :param session: session for the database
     :param version: version of the dashboard
     :return time of the first request in that version
     """
     result = (
-        db_session.query(Request.time_requested)
+        session.query(Request.time_requested)
             .filter(Request.version_requested == version)
             .order_by(Request.time_requested)
             .first()
